==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/group___s_t_b_i_image_codec.js <==
var group___s_t_b_i_image_codec =
[
    [ "STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html", [
      [ "CodecDataPtr", "class_ogre_1_1_s_t_b_i_image_codec.html#a29e31ad112b08ea7fb648b63f426ff1f", null ],
      [ "CodecIterator", "class_ogre_1_1_s_t_b_i_image_codec.html#a21f4b8a16d070793d576f827c9fee218", null ],
      [ "DecodeResult", "class_ogre_1_1_s_t_b_i_image_codec.html#a8cc81c85bd7d4e25393aa153c5e01454", null ],
      [ "STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#af1f778f6c0c79b362906595051dc018a", null ],
      [ "~STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a3a6786b418be005ff8b75b9152c94898", null ],
      [ "encode", "class_ogre_1_1_s_t_b_i_image_codec.html#a2218b499470d28eb0415b3b4f87e5eb3", null ],
      [ "encodeToFile", "class_ogre_1_1_s_t_b_i_image_codec.html#a07b3bd71ae44517eaf316340f09bfd01", null ],
      [ "decode", "class_ogre_1_1_s_t_b_i_image_codec.html#aef0eb6d70068813c59f4be30af564516", null ],
      [ "getType", "class_ogre_1_1_s_t_b_i_image_codec.html#a1763365ccd236b49d56e9c8b60f16844", null ],
      [ "magicNumberToFileExt", "class_ogre_1_1_s_t_b_i_image_codec.html#ad70f382ca4da6f2f55de053f80ebea0e", null ],
      [ "startup", "class_ogre_1_1_s_t_b_i_image_codec.html#af95bb9c106aa7dd901963dd47ccb812b", null ],
      [ "shutdown", "class_ogre_1_1_s_t_b_i_image_codec.html#a6d61006387ccb5c517aec9c397444ac0", null ],
      [ "getDataType", "class_ogre_1_1_s_t_b_i_image_codec.html#a6e9a3bb697c7249e822725eda274615c", null ],
      [ "registerCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a60f445cc6919df56af6611fd14eec47d", null ],
      [ "isCodecRegistered", "class_ogre_1_1_s_t_b_i_image_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557", null ],
      [ "unregisterCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a7aa2599cd9db05e590fb7f7786076852", null ],
      [ "getCodecIterator", "class_ogre_1_1_s_t_b_i_image_codec.html#a55bf1d49e91958f8e412a583666bbd58", null ],
      [ "getExtensions", "class_ogre_1_1_s_t_b_i_image_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1", null ],
      [ "getCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#acc4ee751f92b6e54051393e74e0a2884", null ],
      [ "getCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#ac8775b1052fb8ba72abdfb55df20a6af", null ],
      [ "magicNumberMatch", "class_ogre_1_1_s_t_b_i_image_codec.html#a270be35471eb9ef28fdbd4b7dced21b9", null ]
    ] ],
    [ "STBIPlugin", "class_ogre_1_1_s_t_b_i_plugin.html", null ]
];

==> ogre-docs-1.12.0-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/group___s_t_b_i_image_codec.js <==
var group___s_t_b_i_image_codec =
[
    [ "STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html", [
      [ "CodecDataPtr", "class_ogre_1_1_s_t_b_i_image_codec.html#a29e31ad112b08ea7fb648b63f426ff1f", null ],
      [ "CodecIterator", "class_ogre_1_1_s_t_b_i_image_codec.html#a21f4b8a16d070793d576f827c9fee218", null ],
      [ "DecodeResult", "class_ogre_1_1_s_t_b_i_image_codec.html#a8cc81c85bd7d4e25393aa153c5e01454", null ],
      [ "STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#af1f778f6c0c79b362906595051dc018a", null ],
      [ "~STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a3a6786b418be005ff8b75b9152c94898", null ],
      [ "encode", "class_ogre_1_1_s_t_b_i_image_codec.html#a2218b499470d28eb0415b3b4f87e5eb3", null ],
      [ "encodeToFile", "class_ogre_1_1_s_t_b_i_image_codec.html#a07b3bd71ae44517eaf316340f09bfd01", null ],
      [ "decode", "class_ogre_1_1_s_t_b_i_image_codec.html#aef0eb6d70068813c59f4be30af564516", null ],
      [ "getType", "class_ogre_1_1_s_t_b_i_image_codec.html#a1763365ccd236b49d56e9c8b60f16844", null ],
      [ "magicNumberToFileExt", "class_ogre_1_1_s_t_b_i_image_codec.html#ad70f382ca4da6f2f55de053f80ebea0e", null ],
      [ "startup", "class_ogre_1_1_s_t_b_i_image_codec.html#af95bb9c106aa7dd901963dd47ccb812b", null ],
      [ "shutdown", "class_ogre_1_1_s_t_b_i_image_codec.html#a6d61006387ccb5c517aec9c397444ac0", null ],
      [ "getDataType", "class_ogre_1_1_s_t_b_i_image_codec.html#a6e9a3bb697c7249e822725eda274615c", null ],
      [ "registerCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a60f445cc6919df56af6611fd14eec47d", null ],
      [ "isCodecRegistered", "class_ogre_1_1_s_t_b_i_image_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557", null ],
      [ "unregisterCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#a7aa2599cd9db05e590fb7f7786076852", null ],
      [ "getCodecIterator", "class_ogre_1_1_s_t_b_i_image_codec.html#a55bf1d49e91958f8e412a583666bbd58", null ],
      [ "getExtensions", "class_ogre_1_1_s_t_b_i_image_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1", null ],
      [ "getCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#acc4ee751f92b6e54051393e74e0a2884", null ],
      [ "getCodec", "class_ogre_1_1_s_t_b_i_image_codec.html#ac8775b1052fb8ba72abdfb55df20a6af", null ],
      [ "magicNumberMatch", "class_ogre_1_1_s_t_b_i_image_codec.html#a270be35471eb9ef28fdbd4b7dced21b9", null ]
    ] ],
    [ "STBIPlugin", "class_ogre_1_1_s_t_b_i_plugin.html", [
      [ "getName", "class_ogre_1_1_s_t_b_i_plugin.html#a6bea06e30790dee0469ca92a555adffd", null ],
      [ "install", "class_ogre_1_1_s_t_b_i_plugin.html#a8705ffb916017e9b676da609c16a858a", null ],
      [ "uninstall", "class_ogre_1_1_s_t_b_i_plugin.html#abc0191046c6292bd6695d95b8577ad42", null ],
      [ "initialise", "class_ogre_1_1_s_t_b_i_plugin.html#a9cebe96201c4e0419557a22c9a833c61", null ],
      [ "shutdown", "class_ogre_1_1_s_t_b_i_plugin.html#aa9fa42cc0c7d452940c05a967198501b", null ]
    ] ]
];
